( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins/1.0.0.0__0738eb9f132ed756/Mono.Addins.dll Mono.Addins.dll )
( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.CecilReflector.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins.CecilReflector/1.0.0.0__0738eb9f132ed756/Mono.Addins.CecilReflector.dll Mono.Addins.CecilReflector.dll )
( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.Gui.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins.Gui/1.0.0.0__0738eb9f132ed756/Mono.Addins.Gui.dll Mono.Addins.Gui.dll )
( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.MSBuild.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins.MSBuild/1.0.0.0__0738eb9f132ed756/Mono.Addins.MSBuild.dll Mono.Addins.MSBuild.dll )
( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.Setup.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins.Setup/1.0.0.0__0738eb9f132ed756/Mono.Addins.Setup.dll Mono.Addins.Setup.dll )
